<?php

namespace App\Http\Controllers\Api\v1;

use App\Http\Controllers\Controller;
use App\Http\Requests\Auth\SignInRequest;
use App\Models\User as Users;
use App\Models\TempUsers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Kreait\Firebase\Contract\Database;
use Validator;
use DB;
use \Crypt;
use Hash;
use Carbon\Carbon;

class AuthController extends BaseController
{
    public function __construct(Database $database)
    {
        $this->database = $database;
    }
    public function signup(Request $request)
    {
        try{
            global $DBConnection;
            global $dNow;
            $access_token = '';

            $DBConnection->beginTransaction();

            if (Users::where('email', $request->email)->first() != null) {
                return response()->json([
                    'result' => false,
                    'error' => (object)array(),
                    'message' => 'Email already exists.',
                    'user_id' => 0
                ], 201);
            }

            if (Users::where('phone', $request->phone_number)->first() != null) {
                return response()->json([
                    'result' => false,
                    'error' => (object)array(),
                    'message' => 'Phone already exists.',
                    'user_id' => 0
                ], 201);
            }

            $validator = Validator::make($request->all(), [

                'dial_code' => ['required'],
                'phone_number' => ['required', 'numeric'],
                'user_device_type' => ['required'],
                'user_device_token' => ['required'],
                'first_name' => ['required', 'string', 'max:255'],
                'last_name' => ['required', 'string', 'max:255'],
                'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
                'password' => ['required', 'string', 'min:8', 'confirmed'],
            ]);


            if ($validator->fails()) {
                $status = "0";
                $message = "Please fill all required fields";
                $errors = $validator->messages();
                $message = $validator->messages()->first();

                return response()->json([
                    'result' => false,
                    'message' => $message,
                    'error' => (object)$errors
                ], 200);
            }

            if ( $request->reference_code ) {
                $user_check = Users::where('reference_code', $request->reference_code)->first();

                if ( ! $user_check ) {
                    $status = "0";
                    $message = "Invalid Referral Code.";
                    $errors = $validator->messages();

                    return response()->json([
                        'result' => false,
                        'message' => $message,
                        'error' => (object)$errors
                    ], 200);
                }
            }

            $country_id = 0;
            if ( isset ( $request->intro_access_token ) && $request->intro_access_token != null) {
                $intro_access_token = $request->intro_access_token;
                $intro_access_token = Crypt::decryptString($intro_access_token);
                $intro_access_token = json_decode($intro_access_token);
                if ( isset ($intro_access_token->country_id) && $intro_access_token->country_id != "" ){
                    $country_id = $intro_access_token->country_id;
                }
            }

            $ref_code = strtoupper(GenerateCode());

            if (TempUsers::where('email', $request->email)->first() != null) {

                $user = TempUsers::where('email', $request->email)->first();

                $tokenResult = $user->createToken('Personal Access Token')->accessToken;
                $tokenResult->expires_at = Carbon::now()->addWeeks(100);
                $user->expires_at = Carbon::parse($tokenResult->expires_at)->toDateTimeString();
                $token = $tokenResult->token;
                $user->access_token = $token;
                $user_id = $user->id;

                $user = TempUsers::find($user_id)->update([
                    'name' => $request->first_name . ' ' . $request->last_name,
                    'first_name' => $request->first_name,
                    'last_name' => $request->last_name,
                    'email' => $request->email,
                    'dial_code' => '+'.str_replace('+','', $request->dial_code),
                    'phone_number' => $request->phone_number,
                    'phone_verified'=>0,
                    'user_type' => $request->user_type == 'manager' ? 'manager' : 'user',
                    'device_type' => $request->user_device_type,
                    'fcm_token' => $request->user_device_token ?? '',
                    'device_token' => $request->fcm_token,
                    'password' => Hash::make($request->password),
                    'created_at' => gmdate('Y-m-d H:i:s'),
                    'updated_at' => gmdate('Y-m-d H:i:s'),
                    'phone_otp' => '1111',//rand(100000, 999999),
                    'status' => 1,
                    'access_token' => $token,
                    'country_id' => $country_id,
                    'reference_number' => $ref_code,
                    'referred_by' => strtoupper($request->reference_code) ?? '']);

                $user = TempUsers::where('email', $request->email)->first();

            } else {
                $user = new TempUsers([
                    'name' => $request->first_name . ' ' . $request->last_name,
                    'first_name' => $request->first_name,
                    'last_name' => $request->last_name,
                    'email' => $request->email,
                    'dial_code' => '+'.str_replace('+','', $request->dial_code),
                    'phone_number' => $request->phone_number,
                    'phone_verified'=>0,
                    'user_type' => $request->user_type == 'manager' ? 'manager' : 'user',
                    'device_type' => $request->user_device_type,
                    'fcm_token' => $request->user_device_token ?? '',
                    'device_token' => $request->user_device_token,
                    'password' => Hash::make($request->password),
                    'created_at' => gmdate('Y-m-d H:i:s'),
                    'updated_at' => gmdate('Y-m-d H:i:s'),
                    'phone_otp' => '1111',//rand(100000, 999999)
                ]);
                $user->save();

                $tokenResult = $user->createToken('Personal Access Token')->accessToken;
                $tokenResult->expires_at = Carbon::now()->addWeeks(100);
                $user->expires_at = Carbon::parse($tokenResult->expires_at)->toDateTimeString();
                $token = $tokenResult->token;
                $user->access_token = $token;
                $user_id = $user->id;

                TempUsers::find($user_id)->update(['access_token' => $token]);
            }

            $user->reference_code = $user->reference_number;

            $DBConnection->commit();

            $message    = 'Welcome to '.config('app.name').'. Please verify your account by using verification code :'.$user->phone_otp;
            $phone      = $user->dial_code.$user->phone_number;
            $sms_res    = send_normal_SMS($message, $phone);
           // send_email($user->email, 'Please verify your account', view('email_templates.registrationOTP_mail', compact('user')));

          
           $user = TempUsers::find($user_id);
        $response = ['user' => $user, 'access_token' => $user->access_token];

           $response=convert_all_elements_to_string($response);
           return $this->SuccessResponse($response, 'Login Successful');
            // return $this->loginSuccess($tokenResult, $user,$request->user_device_token);

            // return response()->json([
            //     'result' => true,
            //     'access_token' => $user->access_token,
            //     'message' => 'Registration Successful. Please verify OTP.',
            //     'user' => $user
            // ], 201);
        }catch(\Exception $exception)
        {
            $sMessage = $exception->getMessage();

            unset($aRecords);
            $DBConnection->rollBack();

            $status = "0";
            $message = "we are sorry something went wrong we are trying to fix";
            $errors = $validator->messages();

            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }
    }

    public function resendCode(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'access_token' => 'required',
        ]);

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $user = GetTempUser( $request->access_token );
        if($user){
            $user->phone_otp = '1111';//rand(100000, 999999);
            $user->save();
            try {
                $message    = 'Welcome to '.config('app.name').'. Please verify your account by using verification code :'.$user->phone_otp;
                $phone      = $user->dial_code.$user->phone_number;
                $sms_res    = send_SMS($message, $phone);

                //send_email($user->email, 'Registration Completed Successfully', view('frontend.mail.ResendOTP_mail', compact('user')));
                return response()->json([
                    'result' => true,
                    'message' => 'OTP has been sent to your mobile.',
                ], 200);
            } catch (\Exception $e) {
                // dd($e);
            }
        }

        return response()->json([
            'result' => false,
            'message' => 'unable to send otp.',
        ], 200);
    }

    public function confirmCode(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'phone_otp'      => 'required',
            'access_token' => 'required',
            'user_device_token' => 'required'
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $temp_user = GetTempUser( $request->access_token );

        if ($temp_user && $temp_user->phone_otp == $request->phone_otp) {

            $user = Users::create([
                'name' => $temp_user->first_name . ' ' . $temp_user->last_name,
                'first_name' => $temp_user->first_name,
                'last_name' => $temp_user->last_name,
                'email' => $temp_user->email,
                'dial_code' => '+'.str_replace('+','', $temp_user->dial_code),
                'phone' => $temp_user->phone_number,
                'phone_verified'=>1,
                'verified'=>1,
                'active'=>1,
                'user_type_id' => 0,
                'user_device_type' => $temp_user->device_type,
                'user_device_token' => $temp_user->fcm_token,
                'password' => $temp_user->password,
                'created_at' => gmdate('Y-m-d H:i:s'),
                'updated_at' => gmdate('Y-m-d H:i:s'),
                'email_verified_at' => gmdate('Y-m-d H:i:s'),
                'role' => 2
            ]);

            $tokenResult = $user->createToken('Personal Access Token')->accessToken;

            //SendEmailOnSuccessfullRegister
            //send_email($user->email, 'Registration Completed Successfully', view('front_end.registration_successful', compact('user')));

            /*if( isset (getSiteSettings()[0]->contact_email) )
                send_email(getSiteSettings()[0]->contact_email, 'Registration Completed Successfully', view('frontend.mail.registration_successful_admin', compact('user')));*/

            if ( $user  ) {
                TempUsers::find($temp_user->id)->delete();
                $user = Users::find($user->id);
            }

            return $this->loginSuccess($tokenResult, $user,$request->user_device_token);

        } else {
            return response()->json([
                'result' => false,
                'error' => (object)array(),
                'message' => 'Code does not match, you can request for resending the code',
            ], 200);
        }
    }

    public function login(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'password'      => 'required',
            'email'         => 'required|email',
            'fcm_token' => 'required',
            'device_type' => 'required'
        ]);


        if ($validator->fails()) {
            $status = "0";
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $user = Users::where('email', $request->email)->first();

        if ($user) {
            if (Hash::check($request->password, $user->password)) {

                if ($user->email_verified_at == null) {

                    $tokenResult = $user->createToken('Personal Access Token')->accessToken;
                    $tokenResult->expires_at = Carbon::now()->addWeeks(100);
                    $user->expires_at = Carbon::parse($tokenResult->expires_at)->toDateTimeString();
                    $token = $tokenResult->token;
                    $user->access_token = $token;
                    $user_id = $user->id;
                    Users::find($user_id)->update(['access_token' => $token]);

                    return response()->json(['result' => false,'oTPVerify' => "1",'message' => 'Please verify your account', 'user' => $user], 200);
                }

                if($user->status == 0){
                    return response()->json(['result' => false, 'oTPVerify' => "0",  'message' => 'You are blocked by Admin.', 'error' => (object)array(), 'user' => null], 200);
                }

                if ( isset ( $request->intro_access_token ) && $request->intro_access_token != null) {
                    $intro_access_token = $request->intro_access_token;
                    $intro_access_token = Crypt::decryptString($intro_access_token);
                    $intro_access_token = json_decode($intro_access_token);
                    /*if ( isset ($intro_access_token->country_id) && $intro_access_token->country_id != "" ){
                        $user_id = $user->id;
                        Users::find($user_id)->update(['country_id' => $intro_access_token->country_id]);
                    }*/
                }

                /*if ( $user->id == 364 && $user->reference_code == "" ){
                    $ref_code = strtoupper(GenerateCode());
                    Users::find($user->id)->update(['reference_code' => $ref_code]);
                }*/

                $user = Users::where('id', $user->id)->first();
                $tokenResult = $user->createToken('Personal Access Token')->accessToken;
                return $this->loginSuccess($tokenResult, $user,$request->fcm_token);
            } else {
                return response()->json(['result' => false, 'error' => (object)array(), 'message' => 'incorrect username or password try again', 'user' => null], 200);
            }
        } else {
            return response()->json(['result' => false, 'error' => (object)array(), 'message' => 'incorrect username or password try again', 'user' => null], 200);
        }
    }

    public function FaceIdLogin(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'face_login_id'      => 'required',
            'fcm_token' => 'required',
            'device_type' => 'required'
        ]);


        if ($validator->fails()) {
            $status = "0";
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $user = Users::where('face_login_id', $request->face_login_id)->first();

        if ($user) {

            if ($user->email_verified_at == null) {

                $tokenResult = $user->createToken('Personal Access Token')->accessToken;
                $tokenResult->expires_at = Carbon::now()->addWeeks(100);
                $user->expires_at = Carbon::parse($tokenResult->expires_at)->toDateTimeString();
                $token = $tokenResult->token;
                $user->access_token = $token;
                $user_id = $user->id;
                Users::find($user_id)->update(['access_token' => $token]);

                return response()->json(['result' => false,'oTPVerify' => "1",'message' => 'Please verify your account', 'user' => $user], 200);
            }

            if($user->status == 0){
                return response()->json(['result' => false, 'oTPVerify' => "0",  'message' => 'You are blocked by Admin.', 'error' => (object)array(), 'user' => null], 200);
            }

            $tokenResult = $user->createToken('Personal Access Token')->accessToken;
            return $this->loginSuccess($tokenResult, $user,$request->fcm_token);
        } else {
            return response()->json(['result' => false, 'error' => (object)array(), 'message' => 'Login fail, try again', 'user' => null], 200);
        }
    }

    public function user(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'access_token'  => 'required'
        ]);

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $access_token  = $request->access_token;
        if (isset($access_token) && $access_token != "") {

            $current_user  = Users::where('user_access_token', $access_token)->first();

            if ($current_user == null) {
                $message = "Session Expired please login";
                return response()->json([
                    'result' => false,
                    'message' => $message,
                    'error' => (object)array()
                ], 401);
            } else {

                $current_user->image =$current_user->image != null ?  public_url().$current_user->image : '';

                $current_user->user_area = (object)array();
                if($current_user->area_id && isset($current_user->area_id)){
                    $current_user->user_area  = ServicesAreas::select('id','city_id','area_name','area_status')->where('area_status', 1)->orderBy('id','desc')->where('id', $current_user->area_id)->first();
                }


                $current_user->user_city = (object)array();
                /*if($current_user->user_area && isset($current_user->user_area->city_id)){
                    $current_user->user_city  = ServicesCities::select('id','province_id','city_name','city_name_ar','city_status')->where('city_status', 1)->orderBy('id','desc')->where('id',$current_user->user_area->city_id)->first();
                }else{
                    if ( isset ( $current_user->city_id ) && $current_user->city_id != "" ) {
                        $current_user->user_city  = ServicesCities::select('id','province_id','city_name','city_name_ar','city_status')->where('city_status', 1)->orderBy('id','desc')->where('id',$current_user->city_id)->first();
                    }
                }*/

                $current_user->user_Province = (object)array();
                if($current_user->user_city && isset($current_user->user_city->province_id)){
                    $current_user->user_Province  = ServicesProvinces::select('id','country_id','province_name','province_name_ar','province_status')->where('province_status', 1)->orderBy('id','desc')->where('id',$current_user->user_city->province_id)->first();
                }

                $current_user->user_Country = (object)array();
                if($current_user->country_id && isset($current_user->country_id)){
                    $current_user->user_Country  = ServicesCountries::select('id','country_name','country_name_ar','country_status')->where('country_status', 1)->orderBy('id','desc')->where('id',$current_user->country_id)->first();
                }

                $aUserDoc = [];
               /* if($current_user->id){
                    $aUserProfileDoc = UserProfileDocuments::FROM('user_profile_doc as upd')
                        ->join('update_profile_doc as pd', 'pd.id', '=', 'upd.user_profile_doc_id')->where('user_id', $current_user->id)->get();
                    if ( isset ($aUserProfileDoc) && count ($aUserProfileDoc) > 0 ){
                        foreach($aUserProfileDoc as $index => $doc) {
                            $aUserDoc[] = array
                            (
                                "document_type_title" => $doc->document_type_title,
                                "image_link" => Config('app.PUBLIC_URL').$doc->image_link
                            );
                        }
                    }
                }*/

                $current_user->is_face_login_set = false;
                if ( isset ( $current_user->face_login_id ) && $current_user->face_login_id != null )
                    $current_user->is_face_login_set = true;

                $current_user->user_doc = $aUserDoc;

                return response()->json([
                    'result' => true,
                    'message' => 'Data fetched successfully',
                    'data' => $current_user
                ]);
            }
        }
        $message = "Session Expired.";
        return response()->json([
            'result' => false,
            'message' => $message,
            'error' => (object)array()
        ], 401);
    }

    public function logout(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'access_token' => 'required'
        ]);
        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $user = GetUser($request->access_token);

        if ( !isset ($user) ) {
            $message = "Session Expired please login";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);
        }

        if ($user->access_token != $request->access_token) {
            $message = "Session Expired please login";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);
        }
        $user->access_token = null;
        $user->save();
        return response()->json([
            'result' => true,
            'message' => 'Successfully logged out'
        ]);
    }

    public function socialLogin(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'email'         => 'required|email',
            'name' => 'required',
            'user_device_type' => 'required',
            'user_device_token' => 'required',
            'social_key' => 'required',
        ]);


        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $checker = Users::where('email', $request->email)->where('role', '!=', 2)->first();
        if ($checker) {
            $message = "User already exits with other role";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)[]
            ], 200);
        }

        if (Users::where('email', $request->email)->first() != null) {

            $user = Users::where('email', $request->email)->first();
            if($user->phone_verified == 0){
                $user->phone_verified = 1;
            }
            $user->user_device_token = $request->user_device_token;
            $user->save();

        } else {

            $user = new Users();
            $user->name                 = $request->name;
            $user->first_name           = $request->name;
            $user->email                = $request->email;
            $user->user_device_type     = $request->user_device_type;
            $user->user_device_token    = $request->user_device_token;
            $user->password             = Hash::make($request->social_key);
            $user->phone_verified       = 0;
            $user->verified             = 1;
            $user->role                 = 2;
            $user->user_type_id         = 0;
            $user->social_key           = $request->social_key;
            $user->email_verified_at    = Carbon::now();
            $user->created_at = gmdate('Y-m-d H:i:s');
            $user->updated_at = gmdate('Y-m-d H:i:s');
            $user->login_type = 1;
            $user->active = 1;
            $user->save();

            $user = Users::where('email', $user->email)->first();


            //SendEmailOnSuccessfullRegister
            //send_email($user->email, 'Registration Completed Successfully', view('front_end.registration_successful', compact('user')));
        }

        $tokenResult = $user->createToken('Personal Access Token')->accessToken;
        return $this->loginSuccess($tokenResult, $user,$request->user_device_token);
    }

    protected function loginSuccess($tokenResult, $user,$user_device_token)
    {
        $tokenResult->expires_at = Carbon::now()->addWeeks(100);

        if($user->firebase_user_key == null)
        {
            $fb_user_refrence = $this->database->getReference('Users/')
                ->push([
                    'user_device_token' => $user->user_device_token,
                    'user_name' => $user->name,
                    'email'     => $user->email,
                    'user_id'   => $user->id
                ]);
            $user->firebase_user_key = $fb_user_refrence->getKey();
        } else {
            $this->database->getReference('Users/' . $user->firebase_user_key . '/')->update(['fcm_token' => $user->user_device_token]);
        }

        $user->save();

        $user->image = $user->image != null ? public_url(). $user->image : '';

        $token = $user->createToken($user->id.$user->name.$user->email);
        $response = ['user' => $user, 'access_token' => $token->plainTextToken];
        $userNode = Users::find($user->id);
        $userNode->user_access_token = $response['access_token'];
        $userNode->user_device_token = $user_device_token;
        $userNode->save();

        $user = Users::find($user->id);
        $response = ['user' => $user, 'access_token' => $user->user_access_token];

        $response=convert_all_elements_to_string($response);
        return $this->SuccessResponse($response, 'Login Successful');

        /*return response()->json([
            'result' => true,
            'oTPVerify' => "0",
            'message' => 'Successfully logged in',
            'access_token' => $token,
            'token_type' => 'Bearer',
            'is_guest' => $is_guest,
            'expires_at' => Carbon::parse($tokenResult->expires_at)->toDateTimeString(),
            'user' => $user
        ])*/;
    }

    public function update_profile(Request $request)
    {
        try{

            global $DBConnection;
            global $dNow;

            $DBConnection->beginTransaction();

            $validator = Validator::make($request->all(), [
                'access_token' => 'required',
                /*'city_id'      => 'required',
                'country_id'  => 'required'*/
            ]);

            if ($validator->fails()) {
                $message = "Please fill all required fields";
                $errors = $validator->messages();
                return response()->json([
                    'result' => false,
                    'message' => $message,
                    'error' => (object)$errors
                ], 200);
            }

            if ($request->access_token != null) {
                $current_user  = GetUser($request->access_token);

                if (empty($current_user)) {
                    $message = "Session Expired please login";
                    return response()->json([
                        'result' => false,
                        'message' => $message,
                        'error' => (object)array()
                    ], 200);
                }
                $user = Users::where(['id' => $current_user->id])->first();
                if ($user) {

                    if ( $request->country_id )
                        $user->country_id           = $request->country_id;

                    if ( $request->city_id )
                        $user->city_id           = $request->city_id;

                    if ( $request->company_name )
                        $user->company_name = $request->company_name;

                    $first_name = $user->first_name;
                    $last_name = $user->last_name;

                    if( $request->first_name )
                        $user->first_name = $request->first_name;
                    else
                        $user->first_name = $first_name;

                    if( $request->last_name )
                        $user->last_name = $request->last_name;
                    else
                        $user->last_name = $last_name;

                    $user->name = $user->first_name . ' ' . $user->last_name;

                    $user_type = 'user';

                    /*$aUpdateProfile_doc = UpdateProfileDoc::where('status', 1)->get();
                    $doc_images = array();
                    if ( isset ($aUpdateProfile_doc) && count ($aUpdateProfile_doc) > 0){
                        foreach ($aUpdateProfile_doc as $key => $doc_name) {

                            $is_required = $doc_name->is_required;

                            $doc_id = $doc_name->id;

                            $finder = DB::table('user_profile_doc')->where('user_profile_doc_id', $doc_id)
                                ->where('user_id', $current_user->id)->first();

                            if ($finder)
                                $is_required = 0;

                            $document_type_title = $doc_name->document_type_title;
                            $uploading_key = preg_replace("/\s+/", "", $document_type_title);

                            if ($is_required == 1 && ! $request->file($uploading_key)){
                                //throw new \Exception('upload_required_image');
                            }

                            if($request->file($uploading_key)){
                                $response = image_upload($request,'user_profile_doc',$uploading_key);
                                if($response['status']){
                                    $doc_images[] = array('image_link' => $response['link'], 'user_profile_doc_id' => $doc_name->id);
                                }else{
                                    throw new \Exception('unable_to_upload_image');
                                }
                            }
                        }
                    }*/


                    if($request->file("image")){
                        $response = image_upload($request,$user_type,'image');
                        if($response['status']){
                            $user->user_image = $response['link'];
                        }
                    }

                    $user->save();

                    $user->image = $user->image != null ? public_url().$user->image : '';
                    $message = "Profile Updated Successfully...";

                    //uploadImages
                    $user_id = $current_user->id;
                    if ( isset ($doc_images) && count ($doc_images) > 0 ) {
                        foreach ($doc_images as $index => $doc_img) {
                            $image_link = $doc_img['image_link'];
                            $user_profile_doc_id = $doc_img['user_profile_doc_id'];

                            $if_check = UserProfileDocuments::where('user_id',$user_id)
                                ->where('user_profile_doc_id', $user_profile_doc_id)->first();
                            if( $if_check ) {
                                $i_record_id = $if_check->id;
                                $s_image_link = $if_check->image_link;

                                $delete_row = UserProfileDocuments::find($i_record_id)->DELETE();
                                //remove from server
                                /*$destinationPath = public_path().$s_image_link;
                                File::delete($destinationPath);*/

                            }

                            $aImageRecords = array("user_id" => $user_id, "user_profile_doc_id"=>$user_profile_doc_id, "image_link" => $image_link);
                            UserProfileDocuments::create($aImageRecords);
                        }
                    }

                    $intro_access_token = $request->intro_access_token ?? '';
                    if ( $request->country_id ) {
                        if ( isset ( $request->intro_access_token ) && $request->intro_access_token != null) {
                            $intro_access_token = $request->intro_access_token;
                            $intro_access_token = Crypt::decryptString($intro_access_token);
                            $intro_access_token = json_decode($intro_access_token);
                            if ( isset ($intro_access_token->currency_id) && $intro_access_token->currency_id != "" ){
                                $intro_access_token = Crypt::encryptString(json_encode(array('lang_id' => $intro_access_token->lang_id, 'country_id'=> $request->country_id, 'currency_id'=> $intro_access_token->currency_id)));
                            }else{
                                $intro_access_token = $request->intro_access_token ?? '';
                            }
                        }
                    }

                    $DBConnection->commit();

                    return response()->json([
                        'result' => true,
                        'intro_access_token' => $intro_access_token,
                        'message' => $message,
                        'data' => $user
                    ], 200);
                } else {
                    $message = "error to update profile please try later";
                    return response()->json([
                        'result' => false,
                        'message' => $message,
                        'error' => (object)array()
                    ], 200);
                }
            }

            $message = "Session Expired.";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);

        }catch(\Exception $exception)
        {
            $sMessage = $exception->getMessage();
            echo $sMessage; exit;
            unset($aRecords);
            $DBConnection->rollBack();

            /****************************/
            /*RemoveImagesIfAnyException*/
            /****************************/
            if ( isset ($doc_images) && count ($doc_images) > 0){
                foreach($doc_images as $index => $media) {
                    $destinationPath = public_path().$media['image_link'];
                    File::delete($destinationPath);
                }
            }

            if($sMessage == "unable_to_upload_image")
                $message = $sMessage; //'error to upload images please try again';
            elseif($sMessage == "upload_required_image")
                $message = 'upload all required images please';
            else
                $message = 'some thing went wrong please try again';

            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);
        }
    }
    public function update_profile_pic(Request $request)
    {
        try{

            global $DBConnection;
            global $dNow;

            $DBConnection->beginTransaction();

            $validator = Validator::make($request->all(), [
                'access_token' => 'required'
            ]);

            if ($validator->fails()) {
                $message = "Please fill all required fields";
                $errors = $validator->messages();
                return response()->json([
                    'result' => false,
                    'message' => $message,
                    'error' => (object)$errors
                ], 200);
            }

            if ($request->access_token != null) {
                $current_user  = GetUser($request->access_token);

                if (empty($current_user)) {
                    $message = "Session Expired please login";
                    return response()->json([
                        'result' => false,
                        'message' => $message,
                        'error' => (object)array()
                    ], 200);
                }
                $user = Users::where(['id' => $current_user->id])->first();
                if ($user) {

                    if ( $request->company_name )
                        $user->company_name = $request->company_name;

                    $first_name = $user->first_name;
                    $last_name = $user->last_name;

                    if( $request->first_name )
                        $user->first_name = $request->first_name;
                    else
                        $user->first_name = $first_name;

                    if( $request->last_name )
                        $user->last_name = $request->last_name;
                    else
                        $user->last_name = $last_name;

                    $user->name = $user->first_name . ' ' . $user->last_name;

                    $user_type = 'user';

                    if($request->file("image")){
                        $response = image_upload($request,$user_type,'image');
                        if($response['status']){
                            $user->image = $response['link'];
                        }
                    }

                    $user->save();

                    $user->image = $user->image != null ? public_url().$user->image : '';
                    $message = "Profile Picture Updated Successfully...";

                    //uploadImages
                    $user_id = $current_user->id;
                    if ( isset ($doc_images) && count ($doc_images) > 0 ) {
                        foreach ($doc_images as $index => $doc_img) {
                            $image_link = $doc_img['image_link'];
                            $user_profile_doc_id = $doc_img['user_profile_doc_id'];

                            $if_check = UserProfileDocuments::where('user_id',$user_id)
                                ->where('user_profile_doc_id', $user_profile_doc_id)->first();
                            if( $if_check ) {
                                $i_record_id = $if_check->id;
                                $s_image_link = $if_check->image_link;

                                $delete_row = UserProfileDocuments::find($i_record_id)->DELETE();
                                //remove from server
                                /*$destinationPath = public_path().$s_image_link;
                                File::delete($destinationPath);*/

                            }

                            $aImageRecords = array("user_id" => $user_id, "user_profile_doc_id"=>$user_profile_doc_id, "image_link" => $image_link);
                            UserProfileDocuments::create($aImageRecords);
                        }
                    }

                    $DBConnection->commit();

                    return response()->json([
                        'result' => true,
                        'message' => $message,
                        'data' => $user
                    ], 200);
                } else {
                    $message = "error to update profile please try later";
                    return response()->json([
                        'result' => false,
                        'message' => $message,
                        'error' => (object)array()
                    ], 200);
                }
            }

            $message = "Session Expired.";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);

        }catch(\Exception $exception)
        {
            $sMessage = $exception->getMessage();

            unset($aRecords);
            $DBConnection->rollBack();

            /****************************/
            /*RemoveImagesIfAnyException*/
            /****************************/
            if ( isset ($doc_images) && count ($doc_images) > 0){
                foreach($doc_images as $index => $media) {
                    $destinationPath = public_path().$media['image_link'];
                    File::delete($destinationPath);
                }
            }

            if($sMessage == "unable_to_upload_image")
                $message = 'error to upload images please try again';
            elseif($sMessage == "upload_required_image")
                $message = 'upload all required images please';
            else
                $message = 'some thing went wrong please try again';

            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);
        }
    }
    public function getRequiredDoc(Request $request){

        $language = $request->language ?? 1;

        $validator = Validator::make($request->all(), [
            'access_token' => 'required'
        ]);

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        if ($request->access_token != null) {
            $user  = GetUser($request->access_token);

            if (empty($user)) {
                $message = "Session Expired please login";
                return response()->json([
                    'result' => false,
                    'message' => $message,
                    'error' => (object)array()
                ], 200);
            }
        }


        $user_id = $user->id;

        $aDoc = UpdateProfileDoc::where('status', 1)->get(['id','document_type_title','document_type_title_ar', 'is_required']);

        $aDocuments = array();
        if ( isset ($aDoc) && count ($aDoc) > 0){
            foreach($aDoc as $index => $doc) {

                $doc_id = $doc->id;
                $image_link = '';

                $finder = DB::table('user_profile_doc')->where('user_profile_doc_id', $doc_id)
                    ->where('user_id', $user_id)->first();

                if ($finder){
                    $doc->is_required = 0;
                    $image_link = Config('app.PUBLIC_URL').$finder->image_link;
                }

                $doc->doc_title = $doc->document_type_title;
                $uploading_key = preg_replace("/\s+/", "", $doc->document_type_title);

                if($language == 2)
                    $doc->doc_title = $doc->document_type_title_ar;

                if ($doc->doc_title != "")
                    $aDocuments[] = array('doc_title' => $doc->doc_title, 'is_required' => $doc->is_required, 'image_uploading_key' => $uploading_key, 'image_url' => $image_link);
            }
        }
        return response()->json(
            [
                'result' => true,
                'message' => 'Data fetched successfully',
                'data' => $aDocuments,
            ],
            200
        );
    }
    public function CountriesList(Request $request){

        $language = $request->language ?? 1;

        $sColumn = 'country_name as country_name';
        if($language == 2)
            $sColumn = 'country_name_ar as country_name';

        $aCountries = ServicesCountries::SELECT('id',$sColumn, 'currency_name', 'dial_code')->where('country_status', 1)->get();

        $aCountriesArr = array();

        if ( isset ( $aCountries ) && count ( $aCountries ) ) {
            foreach ( $aCountries as $index => $country ) {
                $country_id = $country->id;
                $country_name = $country->country_name;
                $currency_name = $country->currency_name;
                $dial_code = $country->dial_code;

                $aCountriesArr[] = array
                (
                    "id" => $country_id,
                    "country_name" => $country_name,
                    "currency_name" => $currency_name,
                    "dial_code" => $dial_code,
                    "country_flag" => config('app.PUBLIC_URL').'/uploads/countries_flag/flag.png'
                );
            }
        }

        return response()->json(
            [
                'result' => true,
                'message' => 'Data fetched successfully',
                'data' => $aCountriesArr,
            ],
            200
        );

    }

    public function ProvincesList(Request $request){

        $language = $request->language ?? 1;

        $validator = Validator::make($request->all(), [
            'country_id' => 'required'
        ]);

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $country_id = $request->country_id ?? 0;

        $sColumn = 'province_name as province_name';
        if($language == 2)
            $sColumn = 'province_name_ar as province_name';

        $aData = ServicesProvinces::SELECT('id',$sColumn)->where('country_id', $country_id)->where('province_status', 1)->get();

        return response()->json(
            [
                'result' => true,
                'message' => 'Data fetched successfully',
                'data' => $aData,
            ],
            200
        );

    }

    public function CitiesList(Request $request){

        $language = $request->language ?? 1;

        $validator = Validator::make($request->all(), [
            'country_name' => 'required'
        ]);

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $country_name = $request->country_name ?? 0;

        $country_id = 0;
        if ( ServicesCountries::where('country_name', $country_name)->first() )
            $country_id = ServicesCountries::where('country_name', $country_name)->first()->id;


        $sColumn = 'city_name as city_name';
        if($language == 2)
            $sColumn = 'city_name_ar as city_name';

        $aData = ServicesCities::SELECT('id',$sColumn)->where('country_id', $country_id)->where('city_status', 1)->get();


        return response()->json(
            [
                'result' => true,
                'message' => 'Data fetched successfully',
                'country_id' => $country_id,
                'data' => $aData,
            ],
            200
        );

    }

    public function get_cities_specified_country(Request $request){

        $language = $request->language ?? 1;

        $validator = Validator::make($request->all(), [
            'country_name' => 'required'
        ]);

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }


        return response()->json(
            [
                'result' => true,
                'message' => 'Data fetched successfully',
                'data' => [],
            ],
            200
        );

    }

    public function AreasList(Request $request){

        $language = $request->language ?? 1;

        $validator = Validator::make($request->all(), [
            'city_id' => 'required'
        ]);

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $city_id = $request->city_id ?? 0;

        $sColumn = 'area_name as area_name';
        if($language == 2)
            $sColumn = 'area_name_ar as area_name';

        $aData = ServicesAreas::SELECT('id',$sColumn)->where('city_id', $city_id)->where('area_status', 1)->get();

        return response()->json(
            [
                'result' => true,
                'message' => 'Data fetched successfully',
                'data' => $aData,
            ],
            200
        );

    }

    public function change_password(Request $request)
    {


        $validator = Validator::make(
            $request->all(),
            [
                'access_token'  => 'required',
                'old_password'  => 'required|min:8',
                'password'  => 'required|min:8|confirmed'
            ]
        );

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $user = GetUser($request->access_token);

        if ($request->access_token != $user->access_token) {
            $message = "Session Expired please login";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)[]
            ], 200);
        }

        $login_type = $user->login_type;
        if ( $login_type == 1 ) {
            $message = "Sorry, You can not reset password of social login";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)[]
            ], 200);
        }

        if (Hash::check($request->old_password, $user->password)) {
            if($request->password == $request->old_password){
                $message = "Old password and New password should not be the same.";
                return response()->json([
                    'result' => false,
                    'message' => $message
                ], 200);
            }
            $user->fill([
                'password' => Hash::make($request->password)
            ])->save();

            $message = "Password changed Successfully";
            return response()->json([
                'result' => true,
                'message' => $message
            ], 200);
        } else {
            return response()->json([
                'result' => false,
                'message' => 'Old Password is incorrect',
                'error' => (object)[]
            ], 200);
        }
    }

    public function change_phone(Request $request)
    {
        $user = GetUser($request->access_token);

        if ( ! isset ( $user )) {
            $message = "Session Expired please login";
            $errors = [];
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $validator = Validator::make(
            $request->all(),
            [
                'access_token'  => 'required',
                'dial_code'     => 'required',
                'phone_number'  => 'required|unique:users,phone_number,'.$user->id
            ]
        );

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();

            $error_msg = $validator->getMessageBag()->toArray();

            if ( isset ( $error_msg['phone_number'] ) ) {
                $message = $error_msg['phone_number'][0];
            }

            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        if ($user ) {
            $user->temp_dial_code         = $request->dial_code;
            $user->temp_phone_number      = $request->phone_number;
            $user->phone_otp              = '1111';//rand(100000, 999999);
            $user->save();
            $message    = $user->phone_otp .' is verification code for change mobile request.';
            $phone      = $user->temp_dial_code.$user->temp_phone_number;
            $sms_res    = send_SMS($message, $phone);

            $message = "OTP send successfully on your mobile";
            return response()->json([
                'result' => true,
                'message' => $message
            ], 200);
        }

        $message = "Session Expired please login";
        return response()->json([
            'result' => false,
            'message' => $message,
            'error' => (object)array()
        ], 200);
    }

    public function confirmCodePhone(Request $request)
    {

        $validator = Validator::make(
            $request->all(),
            [
                'access_token'  => 'required',
                'phone_otp'  => 'required'
            ]
        );

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }
        $user  = Users::where('access_token', $request->access_token)->first();
        if ($user == null) {
            $message = "Session Expired please login";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);
        }
        if ($user && $user->phone_otp == $request->phone_otp) {
            $user->dial_code        = $user->temp_dial_code;
            $user->phone     = $user->temp_phone_number;
            $user->phone_verified   = 1;
            $user->phone_otp = null;
            $user->save();

            $tokenResult = $user->createToken('Personal Access Token')->accessToken;

            return $this->loginSuccess($tokenResult, $user,$request->fcm_token);

            /*return response()->json([
                'result' => true,
                'message' => 'Your mobile number is now verified.',
            ], 200);*/
        }
        return response()->json([
            'result' => false,
            'error' => (object)array(),
            'message' => 'OTP does not match, you can request for resending the code',
        ], 200);
    }

    public function resendCodePhone(Request $request)
    {
        $validator = Validator::make(
            $request->all(),
            [
                'access_token'  => 'required',
            ]
        );

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $user  = GetTempUser($request->access_token);

        if ($user == null) {
            $message = "Session Expired please login";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);
        }
        if($user){
            $user->phone_otp = '1111';//rand(100000, 999999);
            $user->save();

            if($user->dial_code && $user->phone_number){

                $message    = $user->phone_otp.'is verification code for change mobile request.';
                $phone      = $user->temp_dial_code.$user->temp_phone_number;
                $sms_res    = send_SMS($message, $phone);

                return response()->json([
                    'result' => true,
                    'message' => 'Verification code is sent again to your mobile.',
                ], 200);
            }
        }
        return response()->json([
            'result' => false,
            'message' => 'unable to send otp. Try again.',
        ], 200);
    }

    public function updateFaceLoginId(Request $request)
    {
        try{

            global $DBConnection;
            global $dNow;

            $DBConnection->beginTransaction();

            $validator = Validator::make($request->all(), [
                'access_token'  => 'required',
            ]);

            if ($validator->fails()) {
                $message = "Please fill all required fields";
                $errors = $validator->messages();
                return response()->json([
                    'result' => false,
                    'message' => $message,
                    'error' => (object)$errors
                ], 200);
            }

            if ($request->access_token != null) {

                $user  = GetUser($request->access_token);

                if (empty($user)) {
                    $message = "Session Expired please login";
                    return response()->json([
                        'result' => false,
                        'message' => $message,
                        'error' => (object)array()
                    ], 200);
                } else {

                    $face_login_id = $request->face_login_id ?? NULL;

                    if ( $user->face_login_id == "" &&  $request->face_login_id == "" )
                        $message = "Face Login already removed!";
                    else{
                        $users_update = Users::find($user->id)->update(['face_login_id' => $face_login_id]);
                        $DBConnection->commit();

                        if( $face_login_id == "" )
                            $message = "Face Login removed successfully!";
                        else
                            $message = "Face Login ID Updated successfully!";
                    }

                    return response()->json([
                        'result' => true,
                        'message' => $message,
                        'error' => (object)array()
                    ], 200);
                }
            }

            $message = "Session Expired.";
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);

        }catch(\Exception $exception)
        {
            $sMessage = $exception->getMessage();

            unset($aRecords);
            $DBConnection->rollBack();

            $message = 'some thing went wrong please try again';

            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)array()
            ], 200);
        }
    }

    public function deleteprofile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'access_token'  => 'required'
        ]);

        if ($validator->fails()) {
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error' => (object)$errors
            ], 200);
        }

        $access_token  = $request->access_token;
        if (isset($access_token) && $access_token != "") {

            $current_user  = Users::where('access_token', $access_token)->first();

            if ($current_user == null) {
                $message = "Session Expired please login";
                return response()->json([
                    'result' => false,
                    'message' => $message,
                    'error' => (object)array()
                ], 401);
            } else {


                Users::where('id', $current_user->id)->delete();



                return response()->json([
                    'result' => true,
                    'message' => 'User deleted successfully!',
                    'data' => ''
                ]);
            }
        }
        $message = "Session Expired.";
        return response()->json([
            'result' => false,
            'message' => $message,
            'error' => (object)array()
        ], 401);
    }

    function signIn(SignInRequest $request)
    {
        $data = $request->validated();
        $credentials = $request->only('email', 'password');
        $user = Users::whereEmail($data['email'])->first();
        if(!is_null($user) && auth()->attempt($credentials)){
            if(isset($data['user_device_token'])){
                $user->update(['user_device_token' => $request->user_device_token,
                    'user_device_type' => $request->user_device_type]);
            }
            $token = $user->createToken($user->id.$user->name.$user->email);
            $response = ['user' => $user, 'access_token' => $token->plainTextToken];
            $userNode = Users::find($user->id);
            $userNode->user_access_token = $response['access_token'];
            $userNode->save();
            $response=convert_all_elements_to_string($response);
            Auth::logoutOtherDevices($request->password);
            if (config('global.server_mode') == 'local') {
                \Artisan::call('update:firebase_node ' . $user->id);
            } else { 
                exec("php " . base_path() . "/artisan update:firebase_node " . $user->id . " > /dev/null 2>&1 & ");
            }
            return $this->SuccessResponse($response, 'Login Successful');
        }else{
            return $this->ErrorResponse(['msg'=>'Invalid credentials'], 'Login Failed');
        }
    }

    function doctor_signIn(SignInRequest $request)
    {
        $data = $request->validated();
        $credentials = $request->only('email', 'password');
        $user = Users::whereEmail($data['email'])->where(['role' => '4', 'user_type_id' => '0', 'users.deleted' => '0'])->first();
        if(!is_null($user) && auth()->attempt($credentials)){
            if(isset($data['user_device_token'])){
                $user->update(['user_device_token' => $request->user_device_token,
                    'user_device_type' => $request->user_device_type]);
            }
            $token = $user->createToken($user->id.$user->name.$user->email);
            $response = ['user' => $user, 'access_token' => $token->plainTextToken];
            $userNode = Users::find($user->id);
            $userNode->user_access_token = $response['access_token'];
            $userNode->save();
            $response=convert_all_elements_to_string($response);
            Auth::logoutOtherDevices($request->password);
            if (config('global.server_mode') == 'local') {
                \Artisan::call('update:firebase_node ' . $user->id);
            } else {
                exec("php " . base_path() . "/artisan update:firebase_node " . $user->id . " > /dev/null 2>&1 & ");
            }
            return $this->SuccessResponse($response, 'Login Successful');
        }else{
            return $this->ErrorResponse(['msg'=>'Invalid credentials'], 'Login Failed');
        }
    }
}
