<?php

namespace App\Http\Controllers\api\v1;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User as Users;
use Validator;
use App\Models\PasswordReset;
use Illuminate\Support\Str;
use App\Http\Controllers\OTPVerificationController;
use DB;
use Carbon\Carbon;
use Hash;
class PasswordResetController extends Controller
{
    public function forgetRequest(Request $request)
    {
        $user = Users::where('email', $request->email)->first();

        if ($user) {

            $login_type = $user->login_type;
            if ( $login_type == "social_login" ) {
                $message = "Sorry, You can not reset password of social login";
                return response()->json([
                    'result' => false,
                    'message' => $message,
                    'error' => (object)[]
                ], 200);
            }

            $token = Str::random(64);
            DB::table('password_reset')->insert([
                'user_id' => $user->id,
                'reset_code' => $token,
                'reset_request_date' => Carbon::now()
            ]);
            try {
                send_email($request->email, 'Forgot Password email', view('front_end.password_reset_mail', compact('user', 'token')));
            } catch (\Exception $e) {
                dd($e);
            }
            return response()->json(['result' => true, 'message' => 'We have e-mailed your password reset link. Please check your inbox.']);
        }

        return response()->json([
            'result' => false,
            'message' => 'User is not found',
        ], 200);
    }

    public function confirmReset(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'password' =>'required|string|min:8|confirmed',
            'user_id'         => 'required',
            'phone_otp' => 'required'
        ]);


        if ($validator->fails()) {
            $status = "0";
            $message = "Please fill all required fields";
            $errors = $validator->messages();
            return response()->json([
                'result' => false,
                'message' => $message,
                'error'=>(object)$errors
            ], 200);
        }

        $user = Users::where(['id'=>$request->user_id])->first();

        if ($user != null) {
            if( $user->phone_otp!= $request->phone_otp){
                return response()->json([
                    'result' => false,'error'=>(object)array(),
                    'message' => 'Invalid verification code',
                ], 200);
            }
            $user->phone_otp = null;
            $user->password = Hash::make($request->password);
            $user->save();
            return response()->json([
                'result' => true,
                'message' => 'Your password is reset.Please login',
            ], 200);
        } else {
            return response()->json([
                'result' => false,'error'=>(object)array(),
                'message' => 'No user is found',
            ], 200);
        }
    }
}
