<?php

namespace App\Http\Controllers\Api\v1;

use App\Http\Requests\Registration\AddBankAndCompanyRequest;
use App\Http\Requests\Registration\AddBankRequest;
use App\Http\Requests\Registration\AddLocationRequest;
use App\Http\Requests\Registration\AddVehicleDetailsRequest;
use App\Http\Requests\Registration\CreateAccountRequest;
use App\Http\Requests\Registration\DeliveryPartnerRequest;
use App\Models\BankdataModel;
use App\Models\UserLocations;
use App\Models\UserVehicle;
use App\Models\VendorModel;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;

class SignupController extends BaseController
{
    function createAccount(CreateAccountRequest $request){
        $data = $request->validated();
        $data['password'] = bcrypt($data['password']);
        if ($request->file("user_image")) {
            $response = image_upload($request, 'users', 'user_image');
            if ($response['status']) {
                $data['user_image'] = $response['link'];
            }
        }
        $data['residence_no'] = $request->residence_no;
        $data['nationality']  = $request->nationality;
        $user = VendorModel::create($data);
        $token = $user->createToken('Personal Access Token')->plainTextToken;
        $user = VendorModel::find($user->id);
        $userNode = VendorModel::find($user->id);
        $userNode->user_access_token = $token;
        $userNode->save();
        $user = convert_all_elements_to_string($user);
        $user->user_id = (string)$user->id;
        return $this->successResponse(['user'=>convert_all_elements_to_string($user->toArray()), 'token'=>$token],'Account Created Successfully');
    }

    function addBankDetails(AddBankRequest $request){
        $bankData = $request->validated();
        $bank = BankdataModel::updateOrCreate(['user_id'=>$request->user_id],$bankData);
        $bank = convert_all_elements_to_string($bank->toArray());
        return $this->successResponse($bank,'Bank Details Added Successfully');
    }

    function addLocation(AddLocationRequest $request){
        $locationData = $request->validated();
        $location = UserLocations::updateOrCreate(['user_id'=>$request->user_id],$locationData);
        return $this->successResponse($location,'Location Added Successfully');

    }
    
    function addBankAndCompany(AddBankAndCompanyRequest $request){
        $data = $request->validated();
        $bank= $request->only(['user_id','account_no','bank_name','iban_code']);
        $company = $request->only(['commercial_license', 'commercial_reg_no','associated_license']);

        if ($request->file("commercial_license")) {
            $response = image_upload($request, 'company', 'commercial_license');
            if ($response['status']) {
                $company['commercial_license'] = $response['link'];
            }
        }

        if ($request->file("associated_license")) {
            $response = image_upload($request, 'company', 'associated_license');
            if ($response['status']) {
                $company['associated_license'] = $response['link'];
            }
        }
 
         $bankinsert =  new BankdataModel();
         $bankinsert->account_no = $request->account_no;
         $bankinsert->bank_name = $request->bank_name;
         $bankinsert->iban_code = $request->iban_code??0;
         $bankinsert->user_id   = $request->user_id;
         $bankinsert->save();
        DB::transaction(function () use ($bank,$company, $request) {
            VendorModel::where('id', '=', $request->user_id)->first()->update($company);
        });
        $res = [
            'bank' => $bank,
            'company' => $company
        ];
        return $this->successResponse($res,'Company & Bank Details Added Successfully');
    }

    function createDevliveryPartner(DeliveryPartnerRequest $request){
        $data = $request->validated();
        if ($request->file("user_image")) {
            $response = image_upload($request, 'users', 'user_image');
            if ($response['status']) {
                $data['user_image'] = $response['link'];
            }
        }
        $data['password'] = bcrypt($data['password']);
        $user = VendorModel::create($data);
        $token = $user->createToken('Personal Access Token')->plainTextToken;
        return $this->successResponse(['user'=>convert_all_elements_to_string($user->toArray()), 'token'=>$token],'Delivery Partner Created Successfully');
    }

    function addVehicleDetails(AddVehicleDetailsRequest $request){

        $data = $request->validated();
        if ($request->file("vehicle_front")) {
            $response = image_upload($request, 'vehicle', 'vehicle_front');
            if ($response['status']) {
                $data['vehicle_front'] = $response['link'];
            }
        }

        if ($request->file("vehicle_back")) {
            $response = image_upload($request, 'vehicle', 'vehicle_back');
            if ($response['status']) {
                $data['vehicle_back'] = $response['link'];
            }
        }

        if ($request->file("vehicle_registration")) {
            $response = image_upload($request, 'vehicle', 'vehicle_registration');
            if ($response['status']) {
                $data['vehicle_registration'] = $response['link'];
            }
        }

        if ($request->file("driving_license")) {
            $response = image_upload($request, 'vehicle', 'driving_license');
            if ($response['status']) {
                $data['driving_license'] = $response['link'];
            }
        }
        UserVehicle::updateOrCreate(['user_id'=>$request->user_id],$data);
        return $this->successResponse($data,'Vehicle Details Added Successfully');
    }


}
