<?php

namespace App\Http\Controllers\Api\v1_old;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\User;
use App\Models\Stories;
use App\Models\StoryMentionss;
use App\Models\HideStory;
use App\Models\BlockUser;
use App\Models\StoryLike;
use App\Models\StoryViews;
use App\Models\StoryReport;
use App\Models\MuteStory;

use Validator;
use DB;
use Carbon\Carbon;

class StoryController extends Controller
{
    //
    private function validateAccesToken($access_token){

      $user = User::where(['user_access_token'=>$access_token])->get();

      if($user->count() == 0){
         http_response_code(401);
              echo json_encode([
                    'status' => "0",
                    'message' => 'Invalid login',
                    'oData' => [],
                    'errors' => (object)[]
                ]);
                exit;

      }else{
          $user=$user->first();
          if($user->active == 1){
            return $user->id;
          }else{
              http_response_code(401);
              echo json_encode([
                    'status' => "0",
                    'message' => 'Invalid login',
                    'oData' => [],
                    'errors' => (object)[]
                ]);
                exit;
              return response()->json([
                    'status' => "0",
                    'message' => 'Invalid login',
                    'oData' => [],
                    'errors' => (object)[]
                ], 401);
                exit;
          }
      }
    }
    private function process_story_data($data=[]){
      $result = [
        'story_id'     => (string)$data->id,
        'caption'     => $data->caption,
        'path'        => $data->path,
        'created_at'  => $data->created_at,
        'time_text'  => $data->created_at->diffForHumans(),
        'updated_at'  => $data->updated_at,
        'user_id'     => (string)$data->user_id,
        'author'      => [],
        'taged_users'  => [],
        'share_url'    => url('/').'/story/'.$data->id
      ];

      if(isset($data->user) && !empty($data->user)){
        $result['user_firebase_key'] = $data->user->firebase_user_key;
        $result['author'] = [
          'name'    => $data->user->name??'',
          'user_name'    => $data->user->user_name??'',
          'user_image' => $data->user->user_image,
          'followed_by_user'=>(string)$data->user->followed_by_user
        ];
      }

      if(isset($data->post_users) && !empty($data->post_users)){
        $result['taged_users'] = [];
        foreach ($data->post_users as $userKey ) {
          $result['taged_users'][]= [
            'id'        => (string)$userKey->user->id,
            'name'      => $userKey->user->name,
            'user_name'      => $userKey->user->user_name,
            'user_image'=> $userKey->user->user_image,
            'firebase_user_key'=>$userKey->user->firebase_user_key
          ];
        }
      }
      return $result;
    }

    public function add_story(REQUEST $request){

        $status   = "0";
        $message  = "";
        $o_data   = [];
        $errors   = [];

        $validator = Validator::make($request->all(), [
            'access_token' => 'required',
            'caption' => 'max:2500',
            'files.*'    => function ($attribute, $value, $fail) {
                $is_image = Validator::make(
                    ['upload' => $value],
                    ['upload' => 'image']
                )->passes();

                $is_video = Validator::make(
                    ['upload' => $value],
                    ['upload' => 'mimetypes:video/avi,video/mpeg,video/quicktime,video/mp4']
                )->passes();

                if (!$is_video && !$is_image) {
                    $fail(':attribute must be image or video.');
                }

                if ($is_video) {
                    $validator = Validator::make(
                        ['video' => $value],
                        ['video' => "max:102400"]
                    );
                    if ($validator->fails()) {
                        $fail(":attribute must be 10 megabytes or less.");
                    }
                }

                if ($is_image) {
                    $validator = Validator::make(
                        ['image' => $value],
                        ['image' => "max:1024"]
                    );
                    if ($validator->fails()) {
                        $fail(":attribute must be one megabyte or less.");
                    }
                }
            }
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        }else{
          $user_id = $this->validateAccesToken($request->access_token);
          DB::beginTransaction();
            try{
              $extra_file_names = [];
              if($request->hasfile('files')) {
                  foreach($request->file('files') as $file)
                  {
                    $dir = config('global.upload_path')."/".config('global.post_image_upload_dir');
                    $file_name2 = time().uniqid().".".$file->getClientOriginalExtension();
                    $file->storeAs(config('global.post_image_upload_dir'),$file_name2,config('global.upload_bucket'));
                    $extra_file_names[] = $file_name2;
                  }
              }

              $post_ids = [];
              foreach($extra_file_names as $file){
                  $post = new Stories();
                  $post->caption = $request->caption??'';
                  $post->path = $file;
                  $post->user_id = $user_id;
                  $post->status  = 1;
                  $post->created_at =  gmdate('Y-m-d H:i:s');
                  $post->save();
                  $post_ids[] = $post->id;
              }


              $peoples = [];
              if($request->peoples != ''){
                $peoples = explode(",",$request->peoples);
              }
              $tag_users = [];
              if(!empty($peoples)){
                foreach($peoples as $people){
                  if($people){
                      foreach($post_ids as $pKey){
                          $tag_users[] = [
                            'user_id'  => $people,
                            'story_id'  => $pKey
                          ];
                      }

                  }
                }
                if(!empty($tag_users)){
                  StoryMentionss::WhereIn('story_id',$post_ids)->delete();
                  StoryMentionss::insert($tag_users);
                }
              }
              DB::commit();
              $status = "1";
              $message = "story added Successfully";
              $data  = Stories::with('post_users','post_users.user','user')
              ->where(['status'=>1,'is_blocked'=>0,'user_id'=>$user_id])
              ->where('created_at', '>=', Carbon::now()->subDay()->toDateTimeString())->orderBy('id','desc')->get();
              foreach($data as $key=>$value){
                $o_data[] = $this->process_story_data($value);
              }


              // foreach($post_ids as $key){
              //     if( config('global.server_mode') == 'local'){
              //       \Artisan::call('send_nottification:story '.$key);
              //     }else{
              //       exec("php ".base_path()."/artisan send_nottification:story ".$key." > /dev/null 2>&1 & ");
              //     }
              // }
              if( config('global.server_mode') == 'local'){
                \Artisan::call('send_nottification:story '.$post_ids[0]);
              }else{
                exec("php ".base_path()."/artisan send_nottification:story ".$post_ids[0]." > /dev/null 2>&1 & ");
              }

            }catch (\Exception $e) {
                DB::rollback();
                $message = "Transaction Faild: ".$e->getMessage();
            }
          }
          return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data], 200);
    }

    public function get_my_own_stories(REQUEST $request){

        $status   = "0";
        $message  = "";
        $o_data   = [];
        $errors   = [];
        $extra_data = [];

        $validator = Validator::make($request->all(), [
            'access_token' => 'required'
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        }else{
              $user_id = $this->validateAccesToken($request->access_token);
              $page = (int)$request->page??1;
              $limit= $request->limit??20;
              $offset = ($page - 1) * $limit;
              // $data  = Stories::with('post_users','post_users.user','user')
              // ->where(['status'=>1,'is_blocked'=>0,'user_id'=>$user_id])
              // ->where('created_at', '>=', Carbon::now()->subDay()->toDateTimeString())->orderBy('id','desc');
              $data = User::with(['stories' => function($query) use($user_id,$offset,$limit) {
                    $query->where('created_at', '>=', Carbon::now()->subDay()->toDateTimeString())->addSelect(['liked_by_user' => StoryLike::select(DB::raw("count(id)"))
                        ->where('user_id', $user_id)
                        ->whereColumn('story_id', 'stories.id')
                    ]);
                    $query->where(['status'=>1,'is_blocked'=>0]);
                    $query->orderBy('id', 'desc')->skip($offset)->take($limit);
                }])->select(['users.name','users.user_name','users.id','users.user_image'])->where('id','=',$user_id);
              $total_count = $data->get()->first()->stories->count();
              $data=$data->get();
              if($data->count() > 0){
                  $status = "1";
                  $message = "Data fetched successfully";
              }else{
                  $message = "no data to show";
              }
              // foreach($data as $key=>$value){
              //   $o_data[] = $this->process_story_data($value);
              // }
              $o_data = convert_all_elements_to_string($data);
              $extra_data['total_count'] = $total_count;
              $extra_data['per_page']    = $limit;
              $extra_data['page']        = $page;
          }
          return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data,'extra_data'=>(object)$extra_data], 200);
    }

    public function remove_story(REQUEST $request){

        $status   = "0";
        $message  = "";
        $o_data   = [];
        $errors   = [];
        $extra_data = [];

        $validator = Validator::make($request->all(), [
            'access_token' => 'required',
            'story_id' => 'required'
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        }else{
              $user_id = $this->validateAccesToken($request->access_token);
              $story_id = $request->story_id??0;
              DB::beginTransaction();
              try{
                  Stories::where(['id'=>$story_id,'user_id'=>$user_id])->delete();
                  DB::commit();
                  $status = "1";
                  $message = "Story removed successfully";
              }catch (\Exception $e) {
                  DB::rollback();
                  $message = "Transaction Faild: ".$e->getMessage();
              }
          }
          return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data,'extra_data'=>(object)$extra_data], 200);
    }

    public function get_stories(REQUEST $request){

        $status   = "0";
        $message  = "";
        $o_data   = [];
        $errors   = [];
        $extra_data = [];

        $validator = Validator::make($request->all(), [
            'access_token' => 'required'
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        }else{
              $user_id = $this->validateAccesToken($request->access_token);
              $page = (int)$request->page??1;
              $limit= $request->limit??20;
              $offset = ($page - 1) * $limit;

              $data = User::with(['stories' => function($query) use($user_id) {
                    $query->where('created_at', '>=', Carbon::now()->subDay()->toDateTimeString())->addSelect(['liked_by_user' => StoryLike::select(DB::raw("count(id)"))
                        ->where('user_id', $user_id)
                        ->whereColumn('story_id', 'stories.id')
                    ]);
                    $query->where(['status'=>1,'is_blocked'=>0]);
                    $query->orderBy('id', 'desc');
                    $query->addSelect(['is_viewed' => StoryViews::select(DB::raw("count(id)"))
                        ->where('user_id', $user_id)
                        ->whereColumn('story_id', 'stories.id')
                    ]);
                    $query->addSelect(['is_muted' => MuteStory::select(DB::raw("count(user_id)"))
                        ->where('mute_user_id', $user_id)
                    ]);
                }])->select(['users.name','users.user_name','users.id','users.user_image'])
              ->addSelect( \DB::raw('(SELECT id FROM stories WHERE user_id = users.id order by id desc limit 1 ) as sort'))

              ->whereIn('id', function($query) use($user_id){
                    $query->select('follow_user_id')
                    ->from('user_follows')
                    ->where('user_id', $user_id);
                })
                ->whereHas('stories',function($query){
                    $query->where('created_at', '>=', Carbon::now()->subDay()->toDateTimeString())->where(['status'=>1,'is_blocked'=>0]);
                })
                ->where('id','!=',$user_id)
                ->whereNotIn('id',HideStory::where(['hidden_user_id'=>$user_id])->select('user_id'))
                ->whereNotIn('id',BlockUser::where(['blocked_user_id'=>$user_id])->select('user_id'))
                ->whereNotIn('id',MuteStory::where(['mute_user_id'=>$user_id])->select('user_id'))
                ->orderBy('sort','desc');

                //echo $user_id; echo $data->toSql();
                $total_count = $data->get()->count();
               $data=$data->skip($offset)->take($limit)->get();
              if($data->count() > 0){
                  $status = "1";
                  $message = "Data fetched successfully";
              }else{
                  $message = "no data to show in friends";
              }
              $o_data['friends'] = convert_all_elements_to_string($data);

              $data_my = User::with(['stories' => function($query) use($user_id,$offset,$limit) {
                    $query->where('created_at', '>=', Carbon::now()->subDay()->toDateTimeString())->addSelect(['liked_by_user' => StoryLike::select(DB::raw("count(id)"))
                        ->where('user_id', $user_id)
                        ->whereColumn('story_id', 'stories.id')
                    ]);
                    $query->where(['status'=>1,'is_blocked'=>0]);
                    $query->orderBy('id', 'desc');
                    $query->addSelect(['is_viewed' => StoryViews::select(DB::raw("count(id)"))
                        ->where('user_id', $user_id)
                        ->whereColumn('story_id', 'stories.id')
                    ]);
                }])->select(['users.name','users.user_name','users.id','users.user_image'])->where('id','=',$user_id)->get();
                $o_data['my'] = convert_all_elements_to_string($data_my);
                if($data_my->count() > 0 || $data->count() >0){
                    $status = "1";
                }
              $extra_data['total_count'] = $total_count;
              $extra_data['per_page']    = $limit;
              $extra_data['page']        = $page;
          }
          return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data,'extra_data'=>(object)$extra_data], 200);
    }

    public function get_story_another_user(REQUEST $request){

        $status   = "0";
        $message  = "";
        $o_data   = [];
        $errors   = [];
        $extra_data = [];

        $validator = Validator::make($request->all(), [
            'access_token' => 'required',
            'user_id'      => 'required'
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        }else{
              $user_id = $this->validateAccesToken($request->access_token);
              $search_user_id = $request->user_id;
              $page = (int)$request->page??1;
              $limit= $request->limit??20;
              $offset = ($page - 1) * $limit;
              $data = User::with(['stories' => function($query) use($search_user_id,$offset,$limit,$user_id) {
                    $query->where('created_at', '>=', Carbon::now()->subDay()->toDateTimeString())->addSelect(['liked_by_user' => StoryLike::select(DB::raw("count(id)"))
                        ->where('user_id', $search_user_id)
                        ->whereColumn('story_id', 'stories.id')
                    ]);
                    $query->where(['status'=>1,'is_blocked'=>0]);
                    $query->orderBy('id', 'desc');
                    $query->addSelect(['is_viewed' => StoryViews::select(DB::raw("count(id)"))
                        ->where('user_id', $user_id)
                        ->whereColumn('story_id', 'stories.id')
                    ]);
                }])->select(['users.name','users.user_name','users.id','users.user_image'])->where('id','=',$search_user_id)->get();
              if($data->count() > 0){
                  $status = "1";
                  $message = "Data fetched successfully";
              }else{
                  $message = "no data to show";
              }
              $o_data['user'] = convert_all_elements_to_string($data);
          }
          return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data,'extra_data'=>(object)$extra_data], 200);
    }

    public function get_user_stories(REQUEST $request){

        $status   = "0";
        $message  = "";
        $o_data   = [];
        $errors   = [];
        $extra_data = [];

        $validator = Validator::make($request->all(), [
            'access_token' => 'required',
            'user_id'      => 'required'
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        }else{
              $user_id = $this->validateAccesToken($request->access_token);
              $search_user_id = $request->user_id;
              $page = (int)$request->page??1;
              $limit= $request->limit??20;
              $offset = ($page - 1) * $limit;
              $data  = Stories::with('post_users','post_users.user','user')
              ->where(['status'=>1,'is_blocked'=>0,'user_id'=>$search_user_id])
              ->whereNotIn('user_id',HideStory::where(['user_id'=>$search_user_id,'hidden_user_id'=>$user_id])->select('user_id'))
              ->whereNotIn('user_id',BlockUser::where(['user_id'=>$search_user_id,'blocked_user_id'=>$user_id])->select('user_id'))
              ->whereNotIn('user_id',MuteStory::where(['user_id'=>$search_user_id,'mute_user_id'=>$user_id])->select('user_id'))
              ->where('created_at', '>=', Carbon::now()->subDay()->toDateTimeString())->orderBy('id','desc');
              $total_count = $data->get()->count();
              $data=$data->skip($offset)->take($limit)->get();
              if($data->count() > 0){
                  $status = "1";
                  $message = "Data fetched successfully";
              }else{
                  $message = "no data to show";
              }
              $o_data = convert_all_elements_to_string($data);
              $extra_data['total_count'] = $total_count;
              $extra_data['per_page']    = $limit;
              $extra_data['page']        = $page;
          }
          return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data,'extra_data'=>(object)$extra_data], 200);
    }

    public function get_story_details(REQUEST $request){

        $status   = "0";
        $message  = "";
        $o_data   = [];
        $errors   = [];
        $extra_data = [];

        $validator = Validator::make($request->all(), [
            'access_token' => 'required',
            'story_id'      => 'required'
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        }else{
              $user_id = $this->validateAccesToken($request->access_token);
              $story_id = $request->story_id;
              $data  = Stories::with('post_users','post_users.user','user')
              ->where(['status'=>1,'is_blocked'=>0,'id'=>$story_id]);
              $data=$data->get();
              if($data->count() > 0){
                  $status = "1";
                  $message = "Data fetched successfully";
                  $o_data = convert_all_elements_to_string($data);
              }else{
                  $message = "no data to show";
              }
          }
          return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data,'extra_data'=>(object)$extra_data], 200);
    }

    public function hide_unhide_story(REQUEST $request){
      $status   = "0";
      $message  = "";
      $o_data   = [];
      $errors   = [];

      $validator = Validator::make($request->all(), [
          'access_token' => 'required',
          'user_id' => 'required|numeric'
      ]);

      if ($validator->fails()) {
          $status = "0";
          $message = "Validation error occured";
          $errors = $validator->messages();
      }else{
        $loged_user_id = $this->validateAccesToken($request->access_token);
        $user_id = $request->user_id;
        $check_exist = HideStory::where(['hidden_user_id'=>$user_id,'user_id'=>$loged_user_id])->get();
        if($check_exist->count() > 0){
          HideStory::where(['hidden_user_id'=>$user_id,'user_id'=>$loged_user_id])->delete();
          $status = "1";
          $message = "un hide";
        }else{
          $like = new HideStory();
          $like->hidden_user_id = $user_id;
          $like->user_id = $loged_user_id;
          $like->created_at =  gmdate('Y-m-d H:i:s');
          $like->save();
          if($like->id >0){
            $status = "1";
            $message = "story hidden";
          }else{
            $message = "faild to hide story";
          }
        }
      }
      return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data], 200);
    }
    public function block_unblock_user(REQUEST $request){
      $status   = "0";
      $message  = "";
      $o_data   = [];
      $errors   = [];

      $validator = Validator::make($request->all(), [
          'access_token' => 'required',
          'user_id' => 'required|numeric'
      ]);

      if ($validator->fails()) {
          $status = "0";
          $message = "Validation error occured";
          $errors = $validator->messages();
      }else{
        $loged_user_id = $this->validateAccesToken($request->access_token);
        $user_id = $request->user_id;
        $check_exist = BlockUser::where(['blocked_user_id'=>$user_id,'user_id'=>$loged_user_id])->get();
        if($check_exist->count() > 0){
          BlockUser::where(['blocked_user_id'=>$user_id,'user_id'=>$loged_user_id])->delete();
          $status = "1";
          $message = "un blocked";

          if( config('global.server_mode') == 'local'){
            \Artisan::call('firebase:block_unblock_user '.$loged_user_id.' '.$user_id.' unblock');
          }else{
            exec("php ".base_path()."/artisan firebase:block_unblock_user ".$loged_user_id.' '.$user_id." unblock > /dev/null 2>&1 & ");
          }

        }else{
          $like = new BlockUser();
          $like->blocked_user_id = $user_id;
          $like->user_id = $loged_user_id;
          $like->created_at =  gmdate('Y-m-d H:i:s');
          $like->save();
          if($like->id >0){
            $status = "1";
            $message = "user blocked";
            if( config('global.server_mode') == 'local'){
              \Artisan::call('firebase:block_unblock_user '.$loged_user_id.' '.$user_id.' block');
            }else{
              exec("php ".base_path()."/artisan firebase:block_unblock_user ".$loged_user_id.' '.$user_id." block > /dev/null 2>&1 & ");
            }
          }else{
            $message = "faild to block user";
          }
        }
      }
      return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data], 200);
    }

    public function mute_unmute_story(REQUEST $request){
      $status   = "0";
      $message  = "";
      $o_data   = [];
      $errors   = [];

      $validator = Validator::make($request->all(), [
          'access_token' => 'required',
          'user_id' => 'required|numeric'
      ]);

      if ($validator->fails()) {
          $status = "0";
          $message = "Validation error occured";
          $errors = $validator->messages();
      }else{
        $loged_user_id = $this->validateAccesToken($request->access_token);
        $user_id = $request->user_id;
        $check_exist = MuteStory::where(['mute_user_id'=>$user_id,'user_id'=>$loged_user_id])->get();
        if($check_exist->count() > 0){
          MuteStory::where(['mute_user_id'=>$user_id,'user_id'=>$loged_user_id])->delete();
          $status = "1";
          $message = "Story unmuted";

          if( config('global.server_mode') == 'local'){
            \Artisan::call('firebase:mute_unmute_story '.$loged_user_id.' '.$user_id.' unmute');
          }else{
            exec("php ".base_path()."/artisan firebase:mute_unmute_story ".$loged_user_id.' '.$user_id." unmute > /dev/null 2>&1 & ");
          }

        }else{
          $like = new MuteStory();
          $like->mute_user_id = $user_id;
          $like->user_id = $loged_user_id;
          $like->created_at =  gmdate('Y-m-d H:i:s');
          $like->save();
          if($like->id >0){
            $status = "1";
            $message = "Story muted";
            if( config('global.server_mode') == 'local'){
              \Artisan::call('firebase:mute_unmute_story '.$loged_user_id.' '.$user_id.' mute');
            }else{
              exec("php ".base_path()."/artisan firebase:mute_unmute_story ".$loged_user_id.' '.$user_id." mute > /dev/null 2>&1 & ");
            }
          }else{
            $message = "faild to mute story";
          }
        }
      }
      return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data], 200);
    }

    public function like_dislike(REQUEST $request){
      $status   = "0";
      $message  = "";
      $o_data   = [];
      $errors   = [];

      $validator = Validator::make($request->all(), [
          'access_token' => 'required',
          'story_id' => 'required|numeric'
      ]);

      if ($validator->fails()) {
          $status = "0";
          $message = "Validation error occured";
          $errors = $validator->messages();
      }else{
        $user_id = $this->validateAccesToken($request->access_token);
        $post_id = $request->story_id;
        $check_exist = StoryLike::where(['story_id'=>$post_id,'user_id'=>$user_id])->get();
        if($check_exist->count() > 0){
          StoryLike::where(['story_id'=>$post_id,'user_id'=>$user_id])->delete();
          $status = "1";
          $message = "disliked";
        }else{
          $like = new StoryLike();
          $like->story_id = $post_id;
          $like->user_id = $user_id;
          $like->created_at =  gmdate('Y-m-d H:i:s');
          $like->save();
          if($like->id >0){
            $status = "1";
            $message = "liked";
          }else{
            $message = "faild to like";
          }
        }
      }
      return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data], 200);
    }

    public function mark_story_viewed(REQUEST $request){
      $status   = "0";
      $message  = "";
      $o_data   = [];
      $errors   = [];

      $validator = Validator::make($request->all(), [
          'access_token' => 'required',
          'story_id' => 'required|numeric'
      ]);

      if ($validator->fails()) {
          $status = "0";
          $message = "Validation error occured";
          $errors = $validator->messages();
      }else{
        $user_id = $this->validateAccesToken($request->access_token);
        $post_id = $request->story_id;
        $check_exist = StoryViews::where(['story_id'=>$post_id,'user_id'=>$user_id])->get();
        if($check_exist->count() > 0){
          $status = "1";
          $message = "already marked as viewed";
        }else{
            try{
              $like = new StoryViews();
              $like->story_id = $post_id;
              $like->user_id = $user_id;
              $like->created_at =  gmdate('Y-m-d H:i:s');
              $like->save();
              if($like->id >0){
                $status = "1";
                $message = "marked as viewed";
              }else{
                $message = "faild to mark as viewed";
              }
          }catch(\Exception $e){
              $message = "try again";
          }
        }
      }
      return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data], 200);
    }
    public function report_story(REQUEST $request)
    {
        $status = "0";
        $message = "";
        $o_data = [];
        $errors = [];

        $validator = Validator::make($request->all(), [
            'access_token' => 'required',
            'story_id' => 'required',
            'reason'  => 'required',
            'problem_id'  => 'required',
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error occured";
            $errors = $validator->messages();
        } else {
            $user_id = $this->validateAccesToken($request->access_token);
            StoryReport::where('user_id',$user_id)->where('story_id',$request->story_id)->delete();
            $data = new StoryReport();
            $data->user_id = $user_id;
            $data->story_id = $request->story_id;
            $data->reason = $request->reason;
            $data->problem_id = $request->problem_id;
            $data->save();

            if ($data->id > 0) {
                $status = "1";
                $message = "Story Reported Successfully. Our team will look into it shortly";
            } else {
                $message = "Faild to report";
            }
        }

        return response()->json(['status' => $status, 'error' => $errors, 'message' => $message, 'oData' => $o_data], 200);
    }
}
