<?php

namespace App\Http\Controllers\doctor;

use App\Http\Controllers\Controller;
use App\Models\BankdataModel;
use App\Models\Cities;
use App\Models\CountryModel;
use App\Models\States;
use App\Models\VendorDetailsModel;
use App\Models\VendorModel;
use App\Models\BlockUser;
use App\Models\UserReport;
use App\Models\PublicBusinessInfos;
use Illuminate\Http\Request;
use Validator;

class DoctorsController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if (!check_permission('doctors', 'View')) {
            abort(404);
        }
        $page_heading = "Doctors";
        $datamain = VendorModel::select('*', 'users.name as name', 'industry_types.name as industry', 'users.active as active', 'users.id as id', 'users.updated_at as updated_at')
            ->where(['role' => '4', 'user_type_id' => '0', 'users.deleted' => '0'])
            ->withCount('doctor_prescribe')
            ->leftjoin('vendor_details', 'vendor_details.user_id', '=', 'users.id')
            ->leftjoin('industry_types', 'industry_types.id', '=', 'vendor_details.industry_type')
            ->orderBy('users.id', 'desc')->get();

        return view('admin.doctor.list', compact('page_heading', 'datamain'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        if (!check_permission('doctors', 'Create')) {
            abort(404);
        }
        $page_heading = "Doctors";
        $mode = "create";
        $id = "";
        $prefix = "";
        $name = "";
        $dial_code = "";
        $image = "";
        $active = "1";
        $states = [];
        $cities = [];
        $countries = CountryModel::orderBy('name', 'asc')->get();
        $business_infos = PublicBusinessInfos::where(['deleted' => 0, 'active' => 1])->get();

        $level_education = VendorModel::LevelOfEducation();

        return view("doctor.doctor.create", compact('page_heading', 'id', 'name', 'dial_code', 'active', 'prefix', 'countries', 'states', 'cities', 'business_infos', 'level_education'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $status = "0";
        $message = "";
        $o_data = [];
        $errors = [];
        $redirectUrl = '';

        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'phone' => 'required',
            'email' => 'required|email',
            // 'last_name' => 'required',
        ]);
        if (!empty($request->password)) {
            $validator = Validator::make($request->all(), [
                'confirm_password' => 'required',
            ]);
        }
        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error Occured";
            $errors = $validator->messages();
        } else {
            $input = $request->all();

            $lemail = strtolower($request->email);
            $luser_name = strtolower($request->user_name);
            $check_user_name_exist = VendorModel::whereRaw("LOWER(user_name) = '$luser_name'")->where('id', '!=', $request->id)->get()->toArray();
            if ($check_user_name_exist) {
                $status = "0";
                $message = "Username should be unique";
                $errors['user_name'] = "Already exist";
                echo json_encode(['status' => $status, 'message' => $message, 'errors' => $errors]);
                die();
            }

            $check_exist = VendorModel::whereRaw("LOWER(email) = '$lemail'")->where('id', '!=', $request->id)->get()->toArray();
            if (empty($check_exist)) {
                $check_exist_phone = VendorModel::where('phone', $request->phone)->where('id', '!=', $request->id)->get()->toArray();
                if (empty($check_exist_phone)) {

                    $ins = [
                        'name' => $request->name,
                        'email' => $request->email,
                        'dial_code' => $request->dial_code,
                        'phone' => $request->phone,
                        'role' => '4', //doctor
                        'first_name' => $request->first_name,
                        'last_name' => $request->last_name,
                        'user_name' => $request->name,
                        'user_type_id' => $request->user_type_id ?? 0,
                        'gender' => $request->gender ?? 1,
                        'dob' => date("Y-m-d",  strtotime($request->dob)),
                        'level_education_id' => $request->level_education_id ?? 0,
                        'licensed_speciality' => $request->licensed_specialty ?? '',
                        'medical_license_number' => $request->medical_license_number ?? '',
                        'nationality' => $request->nationality_id ?? 0
                    ];

                    if ($request->password) {
                        $ins['password'] = bcrypt($request->password);
                    }

                    if ($request->file("logo")) {
                        $response = image_upload($request, 'users', 'logo');
                        if ($response['status']) {
                            $ins['user_image'] = $response['link'];
                        }
                    }

                    $images_data = [];
                    $total_images = 0;
                    if ($request->hasfile("professional_educational_cert")) {
                        /*$response = image_upload($request, 'dr_doc', 'professional_educational_cert');
                        if ($response['status']) {
                            $ins['educational_certificates'] = $response['link'];
                        }*/
                        foreach($request->file('professional_educational_cert') as $image)
                        {
                            $response = file_save($image,'dr_doc', '25');
                            if ($response['status']) {
                                $images_data[$response['link']] = $response['link'];
                            }
                            $total_images++;
                        }
                    }
                    if ( $total_images > 0 )
                        $ins['educational_certificates'] = json_encode($images_data);

                    if ($request->file("upload_medical_license")) {
                        $response = image_upload($request, 'dr_doc', 'upload_medical_license');
                        if ($response['status']) {
                            $ins['medical_license'] = $response['link'];
                        }
                    }

                    if ($request->file("emirates_id")) {
                        $response = image_upload($request, 'dr_doc', 'emirates_id');
                        if ($response['status']) {
                            $ins['emirates_id'] = $response['link'];
                        }
                    }

                    if ($request->id != "") {
                        $ins['updated_at'] = gmdate('Y-m-d H:i:s');
                        $user = VendorModel::find($request->id);

                        if ( $total_images > 0 && isset ( $request->id )) {
                            $old_images = $user->educational_certificates;

                            if(isset ( $old_images ) && count ( $old_images ) > 0) {
                                foreach ( $old_images as $key => $link ) {
                                    if ( $key != "" ) {
                                        $images_data[$key] = $key;
                                    }
                                }
                            }

                            $ins['educational_certificates'] = json_encode($images_data);
                        }

                        $user->update($ins);

                        $vendordata = VendorDetailsModel::where('user_id', $request->id)->first();
                        if (empty($vendordata->id)) {
                            $vendordatils = new VendorDetailsModel();
                            $vendordatils->user_id = $request->id;
                        } else {
                            $vendordatils = VendorDetailsModel::find($vendordata->id);
                        }
                        /*$bankdata = BankdataModel::where('user_id', $request->id)->first();
                        if ($bankdata) {
                            $bankdata->bank_name = $request->bank_name;
                            $bankdata->account_no = $request->account_no;
                            $bankdata->iban_code = $request->iban_code;
                            $bankdata->save();
                        } else {
                            $bankdata = new BankdataModel();
                            $bankdata->bank_name = $request->bank_name;
                            $bankdata->account_no = $request->account_no;
                            $bankdata->iban_code = $request->iban_code;
                            $bankdata->user_id = $request->id;
                            $bankdata->save();
                        }*/

                        $status = "1";
                        $message = "Doctor updated successfully";
                    } else {
                        $ins['created_at'] = gmdate('Y-m-d H:i:s');
                        $userid = VendorModel::create($ins)->id;

                        $vendordatils = new VendorDetailsModel();
                        $vendordatils->user_id = $userid;
                        $vendordatils->updated_at = gmdate('Y-m-d H:i:s');

                        /*$bankdata = new BankdataModel();
                        $bankdata->bank_name = $request->bank_name;
                        $bankdata->account_no = $request->account_no;
                        $bankdata->iban_code = $request->iban_code;
                        $bankdata->user_id = $userid;
                        $bankdata->save();*/

                        $status = "1";
                        $message = "Doctor added successfully";
                    }
                } else {
                    $status = "0";
                    $message = "Phone number should be unique";
                    $errors['phone'] = "Already exist";
                }
            } else {
                $status = "0";
                $message = "Email should be unique";
                $errors['email'] = $request->email . " already added";
            }
        }
        echo json_encode(['status' => $status, 'message' => $message, 'errors' => $errors]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {

        if (!check_permission('doctors', 'Edit')) {
            abort(404);
        }
        $page_heading = "Edit Doctors";
        $datamain = VendorModel::find($id);
        if (!$datamain) {
            abort(404);
        }
        $datamain->vendordatils = VendorDetailsModel::where('user_id', $id)->first();
        // $datamain->bankdetails = BankdataModel::where('user_id', $id)->first();

        $countries = CountryModel::orderBy('name', 'asc')->get();
        $user_image = asset($datamain->user_image);
        $states = States::where(['deleted' => 0, 'active' => 1, 'country_id' => $datamain->country_id])->orderBy('name', 'asc')->get();

        $datamain->bankdetails = BankdataModel::where('user_id', $id)->first();
        $cities = Cities::where(['deleted' => 0, 'active' => 1, 'state_id' => $datamain->state_id])->orderBy('name', 'asc')->get();
        $business_infos = PublicBusinessInfos::where(['deleted' => 0, 'active' => 1])->get();
        $level_education = VendorModel::LevelOfEducation();

        if ($datamain) {
            return view("doctor.doctor.create", compact('page_heading', 'datamain', 'id', 'countries', 'states', 'cities', 'user_image', 'business_infos', 'level_education'));
        } else {
            abort(404);
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function change_status(Request $request)
    {
        $status = "0";
        $message = "";
        if (VendorModel::where('id', $request->id)->update(['active' => $request->status])) {
            $status = "1";
            $msg = "Successfully activated";
            if (!$request->status) {
                $msg = "Successfully deactivated";
            }
            $message = $msg;
        } else {
            $message = "Something went wrong";
        }
        echo json_encode(['status' => $status, 'message' => $message]);
    }
    public function verify(Request $request)
    {
        $status = "0";
        $message = "";
        if (VendorModel::where('id', $request->id)->update(['verified' => $request->status])) {
            $status = "1";
            $msg = "Successfully verified";
            if (!$request->status) {
                $msg = "Successfully updated";
            }
            $message = $msg;
        } else {
            $message = "Something went wrong";
        }
        echo json_encode(['status' => $status, 'message' => $message]);
    }
    public function destroy($id)
    {
        $status = "0";
        $message = "";
        $o_data = [];
        $datatb = VendorModel::find($id);
        if ($datatb) {
            $datatb->deleted = 1;
            $datatb->active = 0;
            $datatb->save();
            $status = "1";
            $message = "Doctor removed successfully";
        } else {
            $message = "Sorry!.. You cant do this?";
        }

        echo json_encode(['status' => $status, 'message' => $message, 'o_data' => $o_data]);
    }
    public function blocked_users(Request $req)
    {
        if (!check_permission('doctors', 'BlockedUsers')) {
            abort(404);
        }
        $customer_id = $req->customer;
        $page_heading = "Blocked doctors";
        $list = BlockUser::with(['user', 'blocked_user']);
        if ($customer_id) {
            $list->where('user_id', $customer_id);
        }
        $list = $list->orderby('created_at', 'desc')->get();
        return view('admin.doctor.blocked_users', compact('page_heading', 'list'));
    }

    public function reported_users(Request $req)
    {
        if (!check_permission('doctors', 'ReportedUsers')) {
            abort(404);
        }
        $customer_id = $req->customer;
        $page_heading = "Reported Doctors";
        $list = UserReport::with(['user', 'report_user']);
        if ($customer_id) {
            $list->where('user_id', $customer_id);
        }
        $list = $list->orderby('created_at', 'desc')->get();
        return view('admin.doctor.reported_users', compact('page_heading', 'list'));
    }

    public function removeEducationalCertificate(Request $request)
    {

        $dr_id = $request->dr_id ?? 0;
        $image = $request->image ?? '';
        $img_name = '';

        $datatb = VendorModel::find($dr_id);

        if ( isset ( $datatb ) ) {
            if(isset($datatb->educational_certificates[$image]))
            {
                $images = $datatb->educational_certificates;
                $img_name = $images[$image];
                unset($images[$image]);

                $datatb->educational_certificates = json_encode($images);
                $datatb->save();
            }
        }

        if (file_exists($img_name))
            unlink($img_name);
        //deleteFile('storage/dr_doc/'.$image);

        $status = "1";
        $message = "Document removed successfully";
        echo json_encode(['status' => $status, 'message' => $message]);
    }
}
