<?php

namespace App\Http\Controllers\doctor;

use App\Http\Controllers\Controller;
use App\Models\PrescribeMedicines;
use Illuminate\Http\Request;
use App\Models\VendorModel;
use Validator;
use PDF;
use Auth;

class PrescribeMedicinesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        if (!check_permission('prescribe_medicines', 'View')) {
            abort(404);
        }

        $user_id = 0;
        $dr_id = 0;

        if ( isset ( $_GET['ur'] ) && $_GET['ur'] > 0) {
            $user_id = $_GET['ur'];
        }

        if ( isset ( $_GET['dr'] ) && $_GET['dr'] > 0) {
            $dr_id = $_GET['dr'];
        }

        if ( $dr_id <= 0 )
            $dr_id = Auth::user()->id;

        $page_heading = "Prescription";
        $datamain = PrescribeMedicines::with(['doctor', 'user'])
            ->where(function ($query) use($user_id, $dr_id){

                if (isset ( $user_id ) && $user_id > 0){
                    $query->where('user_id', $user_id);
                }
                if (isset ( $dr_id ) && $dr_id > 0){
                    $query->where('doctor_id', $dr_id);
                }
            })->orderBy('id', 'desc')->get();
        return view('doctor.dr_prescribe_medicines.list', compact('page_heading', 'datamain', 'dr_id', 'user_id'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {

        if (!check_permission('prescribe_medicines', 'Create')) {
            abort(404);
        }

        $page_heading = "Prescription";
        $id = "";

        $dr_name = '';
        $dr_id = '';

        $user_name = '';
        $user_id = '';

        if ( isset ( $_GET['dr'] ) && $_GET['dr'] != "" ) {
            $doctor_id = (int) $_GET['dr'];
            if ( $doctor_id ) {
                $doctor_name = VendorModel::where("role", 4)->where("active", 1)->where('id', $doctor_id)->first();
                if ( $doctor_name ) {
                    $dr_name = $doctor_name->name;
                    $dr_id = $doctor_name->id;
                }
            }
        }

        if ( isset ( $_GET['ur'] ) && $_GET['ur'] != "" ) {
            $user_id = (int) $_GET['ur'];

            if ( $user_id ) {
                $ur_name = VendorModel::where("role", 2)->where("active", 1)->where('id', $user_id)->first();

                if ( $ur_name ) {
                    $user_name = $ur_name->name;
                    $user_id = $ur_name->id;
                }
            }
        }

        $user = VendorModel::where("role", 2)->where("active", 1)->get();
        $doctor = VendorModel::where("role", 4)->where("active", 1)->get();

        return view("doctor.dr_prescribe_medicines.create", compact('page_heading','id', 'user', 'doctor', 'dr_name', 'dr_id', 'user_name', 'user_id'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $status = "0";
        $message = "";
        $o_data = [];
        $errors = [];
        $redirectUrl = '';

        $validator = Validator::make($request->all(), [
            'doctor' => 'required',
            'user' => 'required',
            'title' => 'required',
            'detail' => 'required',
        ]);

        if ($validator->fails()) {
            $status = "0";
            $message = "Validation error Occured";
            $errors = $validator->messages();
        } else {

            $input = $request->all();
            $lemail = strtolower($request->email);
            $luser_name = strtolower($request->user_name);

            $ins = [
                'doctor_id' => $request->doctor,
                'user_id' => $request->user,
                'title' => $request->title,
                'detail' => $request->detail
            ];

            if ($request->id != "") {

                $ins['updated_at'] = gmdate('Y-m-d H:i:s');
                $prescribe_medicines = PrescribeMedicines::find($request->id);
                $prescribe_medicines->update($ins);
                $status = "1";
                $message = "Prescription updated successfully";

            } else {

                $ins['created_at'] = gmdate('Y-m-d H:i:s');
                PrescribeMedicines::create($ins)->id;

                $status = "1";
                $message = "Prescription added successfully";
            }

        }
        echo json_encode(['status' => $status, 'message' => $message, 'errors' => $errors]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        if (!check_permission('prescribe_medicines', 'View')) {
            abort(404);
        }

        $page_heading = "View Prescription";

        $datarow = PrescribeMedicines::with(['doctor', 'user'])->where('id', $id)->first();

        if (!$datarow) {
            abort(404);
        }

        if ($datarow) {
            return view("doctor.dr_prescribe_medicines.view", compact('page_heading', 'datarow', 'id'));
        } else {
            abort(404);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {

        if (!check_permission('prescribe_medicines', 'Edit')) {
            abort(404);
        }

        $page_heading = "Edit Prescription";

        $datamain = PrescribeMedicines::with(['doctor', 'user'])->where('id', $id)->first();

        if (!$datamain) {
            abort(404);
        }


        $dr_id = Auth::user()->id;
        $dr_name = '';

        if ( isset ( $dr_id ) && $dr_id != "" ) {
            $doctor_id = $dr_id;
            if ( $doctor_id ) {
                $doctor_name = VendorModel::where("role", 4)->where("active", 1)->where('id', $doctor_id)->first();
                if ( $doctor_name ) {
                    $dr_name = $doctor_name->name;
                }
            }
        }

        $user = VendorModel::where("role", 2)->where("active", 1)->get();
        $doctor = VendorModel::where("role", 4)->where("active", 1)->get();

        if ($datamain) {
            return view("doctor.dr_prescribe_medicines.create", compact('page_heading', 'datamain', 'user', 'doctor', 'id', 'dr_name', 'dr_id'));
        } else {
            abort(404);
        }
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function change_status(Request $request)
    {
        $status = "0";
        $message = "";
        if (VendorModel::where('id', $request->id)->update(['active' => $request->status])) {
            $status = "1";
            $msg = "Successfully activated";
            if (!$request->status) {
                $msg = "Successfully deactivated";
            }
            $message = $msg;
        } else {
            $message = "Something went wrong";
        }
        echo json_encode(['status' => $status, 'message' => $message]);
    }
    public function verify(Request $request)
    {
        $status = "0";
        $message = "";
        if (VendorModel::where('id', $request->id)->update(['verified' => $request->status])) {
            $status = "1";
            $msg = "Successfully verified";
            if (!$request->status) {
                $msg = "Successfully updated";
            }
            $message = $msg;
        } else {
            $message = "Something went wrong";
        }
        echo json_encode(['status' => $status, 'message' => $message]);
    }
    public function destroy($id)
    {
        $status = "0";
        $message = "";
        $o_data = [];
        $datatb = PrescribeMedicines::find($id)->delete();

        $status = "1";
        $message = "Prescription removed successfully";

        echo json_encode(['status' => $status, 'message' => $message, 'o_data' => $o_data]);
    }
    public function blocked_users(Request $req)
    {
        if (!check_permission('doctors', 'BlockedUsers')) {
            abort(404);
        }
        $customer_id = $req->customer;
        $page_heading = "Blocked doctors";
        $list = BlockUser::with(['user', 'blocked_user']);
        if ($customer_id) {
            $list->where('user_id', $customer_id);
        }
        $list = $list->orderby('created_at', 'desc')->get();
        return view('doctor.doctor.blocked_users', compact('page_heading', 'list'));
    }

    public function reported_users(Request $req)
    {
        if (!check_permission('doctors', 'ReportedUsers')) {
            abort(404);
        }
        $customer_id = $req->customer;
        $page_heading = "Reported Doctors";
        $list = UserReport::with(['user', 'report_user']);
        if ($customer_id) {
            $list->where('user_id', $customer_id);
        }
        $list = $list->orderby('created_at', 'desc')->get();
        return view('admin.doctor.reported_users', compact('page_heading', 'list'));
    }

    public function removeEducationalCertificate(Request $request)
    {

        $dr_id = $request->dr_id ?? 0;
        $image = $request->image ?? '';
        $img_name = '';

        $datatb = VendorModel::find($dr_id);

        if ( isset ( $datatb ) ) {
            if(isset($datatb->educational_certificates[$image]))
            {
                $images = $datatb->educational_certificates;
                $img_name = $images[$image];
                unset($images[$image]);

                $datatb->educational_certificates = json_encode($images);
                $datatb->save();
            }
        }

        if (file_exists($img_name))
            unlink($img_name);
        //deleteFile('storage/dr_doc/'.$image);

        $status = "1";
        $message = "Document removed successfully";
        echo json_encode(['status' => $status, 'message' => $message]);
    }
    public function generatePDF( $id = 0 ){

        $datamain = PrescribeMedicines::with(['doctor', 'user'])->where('id', $id)->first();

        if (!$datamain) {
            abort(404);
        }

        /*echo "<pre>";
        print_r($datamain);
        exit;*/
        $level_edu_id = $datamain->doctor->level_education_id;
        $user_name = $datamain->user->name ?? 'user';

        $level_edu = VendorModel::LevelOfEducation($level_edu_id);

        $pdf = PDF::loadView('admin.dr_prescribe_medicines.prescription_pdf', compact('datamain', 'level_edu'));

        $date = date("Y-m-d");
        return $pdf->download($date.'-'.$user_name.'.pdf');
    }
}
